DropDown class

Constructors

Properties

bottomSheetListener BottomSheetListener?
bottomSheetListener that listens for BottomSheet bubbling up the tree.
final
bottomSheetTitle Widget?
This gives the bottom sheet title.
final
buttonPadding EdgeInsets?
final
cancelButtonChild Widget?
final
color Color?
final
customTopWidget Widget?
final
data List<SelectedListItem>
This will give the list of data.
final
This will set the background color to the dropdown.
final
enableMultipleSelection bool
This will give selection choice for single or multiple for list.
final
fromSide bool
final
hashCode int
The hash code for this object.
no setterinherited
hintText String?
final
inputDescriptionWidget Widget?
getter/setter pair
isDismissible bool
isDismissible Specifies whether the bottom sheet will be dismissed when user taps on the scrim. If true, the bottom sheet will be dismissed when user taps on the scrim. by default it is True.
final
isSearchVisible bool
isSearchVisible flag use to manage the search widget visibility by default it is True so widget will be visible.
final
labelText String?
final
listItemBuilder ListItemBuilder?
listItemBuilder will gives index as a function parameter and you can return your own widget based on index.
final
margin EdgeInsetsGeometry?
getter/setter pair
noCloseDialog bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchHintText String?
searchHintText is use to show the hint text into the search widget. by default it is Search text.
final
searchWidget TextFormField?
searchWidget is use to show the text box for the searching. If you are passing your own widget then you must have to add TextEditingController for the TextFormField.
final
selectedColor Color?
final
selectedItems SelectedItemsCallBack?
This will give the call back to the selected items from list.
final
showDoneOnHeader bool
final
showRadioButton bool
showRadioButton by default it is True so widget will be visible.
final
submitButtonChild Widget?
You can set your custom submit button when the multiple selection is enabled.
final
submitButtonFlex int?
final
textStyle TextStyle?
final
textStyleSelected TextStyle?
final
widthSide double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited