DropDownNumerical class

Constructors

Properties

bottomSheetListener BottomNumSheetListener?
bottomSheetListener that listens for BottomSheet bubbling up the tree.
final
bottomSheetTitle Widget?
This gives the bottom sheet title.
final
buttonPadding EdgeInsets?
final
cancelButtonChild Widget?
final
customTopWidget Widget?
final
decimalPlace int?
final
description String?
final
This will set the background color to the dropdown.
final
fromSide bool
final
hashCode int
The hash code for this object.
no setterinherited
hintText String?
final
inputDescriptionWidget Widget?
getter/setter pair
isDismissible bool
isDismissible Specifies whether the bottom sheet will be dismissed when user taps on the scrim. If true, the bottom sheet will be dismissed when user taps on the scrim. by default it is True.
final
labelText String?
final
margin EdgeInsetsGeometry?
getter/setter pair
maxValue double?
final
minValue double?
final
newSetCallBack NewSetCallBack?
final
noAcceptMax bool
final
noCloseDialog bool
final
rangeCallBack RangeCallBack?
final
ratioRange double?
final
refreshItems ListItemsCallBack?
This will give the call back to the selected items from list.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDoneOnHeader bool
final
submitButtonChild Widget?
You can set your custom submit button when the multiple selection is enabled.
final
submitButtonFlex int?
final
textStyle TextStyle?
final
txtAdd String?
final
txtAverage String?
final
txtDeviation String?
final
valuesList List<double>
getter/setter pair
valuesListInit List<double>?
final
vibrateOnOutRange bool
final
widthSide double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited