NumPadBody class

This is main class to display the bottom sheet body.

Inheritance

Constructors

NumPadBody({required DropDownNumerical dropDownNumerical, required bool fromSide, String? txtAverage, String? txtDeviation, String? txtAdd, Widget? header, double? minValue, double? maxValue, bool vibrateOnOutRange = true, bool noAcceptMax = true, int? decimalPlace = 0, Widget? descriptionWidget, InputDecoration? currentValueDecoration, TextStyle? currentValueTextStyle = const TextStyle(fontSize: 13, color: Colors.black), bool? noCloseDialog = false, Key? key})
const

Properties

currentValueDecoration InputDecoration?
final
currentValueTextStyle TextStyle?
final
decimalPlace int?
final
descriptionWidget Widget?
final
final
fromSide bool
final
hashCode int
The hash code for this object.
no setterinherited
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxValue double?
final
minValue double?
final
noAcceptMax bool
final
noCloseDialog bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
txtAdd String?
final
txtAverage String?
final
txtDeviation String?
final
vibrateOnOutRange bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NumPadBody>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited